#!/bin/sh
###############################################################################
##
##          DELL INC. PROPRIETARY INFORMATION
##
##  This software is supplied under the terms of a license agreement or
##  nondisclosure agreement with Dell Inc. and may not be copied or disclosed
##  except in accordance with the terms of that agreement.
##
##  Copyright (c) 2003-2006 Dell, Inc. All Rights Reserved.
##
##  Abstract/Purpose:
##    Script is used to:
##      - verify minimum hapi rpm versions for ipmi blocking
##
##  Environment:
##    Linux
##
##  Version:
##    $Revision $
##
##  Last Modified by/on:
##    $Author: Jeff Glanz / $Date: January 2006
##
###############################################################################
typeset -ri _TRUE=0 2>/dev/null
typeset -ri _FALSE=1 2>/dev/null
typeset -ri _VERBOSE=$_FALSE 2>/dev/null
bVerbose() {
    [ $_VERBOSE -eq $_TRUE ]
}

typeset -r _INST_DVR_SERVICE_BASENAME=instsvcdrv
typeset -r _INST_DVR_SERVICE_NAME=/etc/init.d/$_INST_DVR_SERVICE_BASENAME

typeset _HAPI_RPM_VERSION
typeset -r _HAPI_RPM_VERSION_THRESHOLD=${1:-"5.0.0"}
typeset -r _VALID_HAPI_RPM_NAME_0=srvadmin-hapi
typeset -r _VALID_HAPI_RPM_NAME_1=srvadmin-hapi-dtk

function isDisneyInstalled() {
    local hapi_rpm
    typeset -a hapi_rpm_array=(\
        srvadmin-hapi-dtk \
        srvadmin-hapi \
        instsvc-drivers \
        serveradministrator-hapi \
        dellomsa-drivers)

    # first check if any of the above rpms
    # is directly installed
    for hapi_rpm in ${hapi_rpm_array[@]}; do
        _DVR_NAME=$(rpm -q $hapi_rpm --queryformat %{NAME}) || {
            unset _DVR_NAME
            continue
        }
        bVerbose && rpm -q $_DVR_NAME
        break
    done

    # if none of the above rpms is directly installed,
    # check if instvc-drivers is provided by some other rpm
    [ -z "${_DVR_NAME}" ] && {
        _DVR_NAME=$(rpm -q --whatprovides instsvc-drivers --queryformat %{NAME}) || unset _DVR_NAME
    }

    # Default to instsvc if 
    #  - the instsvcdrv service is present
    #  - no rpm is discovered
    [ -f ${_INST_DVR_SERVICE_NAME} -a -z "$_DVR_NAME" ] && _DVR_NAME=instsvc-drivers

    if [ -z "$_DVR_NAME" ]; then
        bVerbose && echo "No Drivers are installed"
        return $_FALSE
    fi
    bVerbose && echo "Drivers are installed, getting version for $hapi_rpm"
    _HAPI_RPM_VERSION=$(rpm -q $hapi_rpm --queryformat %{VERSION}) || unset _HAPI_RPM_VERSION
    return $_TRUE
}

if isDisneyInstalled; then
    bVerbose && echo "dvr_name: $_DVR_NAME"
    bVerbose && echo "dvr_version: $_HAPI_RPM_VERSION"
    [[ "$_DVR_NAME" == "$_VALID_HAPI_RPM_NAME_0" ||
       "$_DVR_NAME" == "$_VALID_HAPI_RPM_NAME_1" ]] || {
        bVerbose && echo "HAPI driver $_DVR_NAME not = $_VALID_HAPI_RPM_NAME_0 or $_VALID_HAPI_RPM_NAME_1"
        return $_FALSE
    }
    [[ "$_HAPI_RPM_VERSION_THRESHOLD" > "$_HAPI_RPM_VERSION" ]] && {
        bVerbose && echo "HAPI version too low"
        return $_FALSE
    }
fi
return $_TRUE
